/*
 * Copyright (c) 2001 David I. Bell
 * Permission is granted to use, distribute, or modify this source,
 * provided that this copyright notice remains intact.
 */

import java.io.FilterOutputStream;
import java.io.OutputStream;
import java.io.IOException;


/**
 * An output filter which counts the number of bytes written
 * using a Counter object.
 */
public class CounterOutputFilter extends FilterOutputStream
{
	protected Counter mCounter = new Counter();


	public CounterOutputFilter(OutputStream outputStream)
	{
		super(outputStream);
	}


	public void setCounter(Counter counter)
	{
		mCounter = counter;
	}


	public Counter getCounter()
	{
		return mCounter;
	}


	public void write(int data) throws IOException
	{
		out.write(data);

		if (mCounter != null)
			mCounter.addCount(1);
	}


	public void write(byte[] buffer) throws IOException
	{
		out.write(buffer);

		if (mCounter != null)
			mCounter.addCount(buffer.length);
	}


	public void write(byte[] buffer, int offset, int count)
		throws IOException
	{
		out.write(buffer, offset, count);

		if (mCounter != null)
			mCounter.addCount(count);
	}
}
